@@ -1,5 +1,5 @@
 from typing import List, Dict
-
+from .utils import normalize_sample
 
 __all__ = ["accessions", "download_urls"]
 
@@ -17,6 +17,7 @@ def download_urls(biosample: Dict) -> List:
     """Return list of download url from given biosample files.
         biosample: Dict, the response of a biosample request.
     """
+
     return [
-        f["cloud_metadata"]["url"] for f in biosample["files"]
+        f["cloud_metadata"]["url"] for f in normalize_sample(biosample)["files"]
     ]
